#ifndef KCRUMB_H
#define KCRUMB_H

#include <QTabBar>
#include "kcustomtabbar.h"

namespace kdk
{
/**
 *  @defgroup KCrumb
 *  @since 2.5
 */
class KCrumbPrivate;

/**
 * @brief KCrumbType，包括两种类型。
 */
enum KCrumbType
{
    FlatBreadCrumb,
    CubeBreadCrumb
};

/**
 * @brief 面包屑控件
 */
class KCrumb : public KCustomTabBar
{
    Q_OBJECT

public:
    explicit KCrumb(QWidget *parent = nullptr);

    /**
     * @brief 添加tab
     * @param text
     * @return
     */
    int addTab(const QString &text);

    /**
     * @brief 添加tab
     * @param icon
     * @param text
     * @return
     */
    int addTab(const QIcon &icon, const QString &text);

    /**
     * @brief 在index位置插入tab
     * @param index
     * @param text
     * @return
     */
    int insertTab(int index, const QString &text);

    /**
     * @brief 在index位置插入tab
     * @param index
     * @param icon
     * @param text
     * @return
     */
    int insertTab(int index, const QIcon&icon, const QString &text);

    /**
     * @brief 删除index位置的tab
     * @param index
     */
    void removeTab(int index);

    /**
     * @brief 将from位置tab移至to位置
     * @param from
     * @param to
     */
    void moveTab(int from, int to);

    /**
     * @brief 设置图标
     * @param icon
     */
    void setIcon(const QIcon &icon);

    /**
     * @brief 获取图标
     * @return
     */
    QIcon icon() const;

    /**
     * @brief 返回按钮边框是否凸起
     * @return
     */
    bool  isFlat() const;

    /**
     * @brief 设置按钮边框是否凸起
     * @param flat
     */
    void  setFlat(bool flat);

public slots:
    void leftScroll();
    void rightScroll();

protected:
    QSize tabSizeHint(int index) const;
    void paintEvent(QPaintEvent *event);

private:
    Q_DECLARE_PRIVATE(KCrumb)
    KCrumbPrivate*const d_ptr;
};
}


#endif // KCRUMB_H
